lists.openwall.net   lists  /  announce  owl-users  owl-dev  john-users  john-dev  passwdqc-users  yescrypt  popa3d-users  /  oss-security  kernel-hardening  musl  sabotage  tlsify  passwords  /  crypt-dev  xvendor  /  Bugtraq  Full-Disclosure  linux-kernel  linux-netdev  linux-ext4  linux-hardening  linux-cve-announce  PHC 
Open Source and information security mailing list archives
 
Hash Suite: Windows password security audit tool. GUI, reports in PDF.
[<prev] [next>] [<thread-prev] [thread-next>] [day] [month] [year] [list]
Date:   Tue, 25 Oct 2022 23:37:06 +0000
From:   Tanjuate Brunostar <tanjubrunostar0@...il.com>
To:     gregkh@...uxfoundation.org
Cc:     linux-staging@...ts.linux.dev, linux-kernel@...r.kernel.org,
        outreachy@...ts.linux.dev,
        Tanjuate Brunostar <tanjubrunostar0@...il.com>
Subject: [PATCH 10/17] staging: vt6655: changed variable name: s_vGenerateTxParameter

change variable names s_vGenerateTxParameter to meet the
linux coding standard, as it says to avoid using camelCase naming
style. Cought by checkpatch

Signed-off-by: Tanjuate Brunostar <tanjubrunostar0@...il.com>
---
 drivers/staging/vt6655/rxtx.c | 63 ++++++++++++++++++-----------------
 1 file changed, 32 insertions(+), 31 deletions(-)

diff --git a/drivers/staging/vt6655/rxtx.c b/drivers/staging/vt6655/rxtx.c
index 3d28cbfec618..fa11677ce119 100644
--- a/drivers/staging/vt6655/rxtx.c
+++ b/drivers/staging/vt6655/rxtx.c
@@ -10,7 +10,7 @@
  * Date: May 20, 2003
  *
  * Functions:
  *      s_vGenerateTxParameter - Generate tx dma required parameter.
  *      vGenerateMACHeader - Translate 802.3 to 802.11 header
  *      cbGetFragCount - Calculate fragment number count
  *      csBeacon_xmit - beacon tx function
@@ -95,23 +95,24 @@ static void s_v_fill_rts_head(struct vnt_private *p_device,
 			      unsigned short wCurrentRate,
 			      unsigned char by_fb_option);
 
-static void s_vGenerateTxParameter(struct vnt_private *p_device,
-				   unsigned char by_pkt_type,
-				   struct vnt_tx_fifo_head *,
-				   void *pvRrvTime,
-				   void *pv_rts,
-				   void *pvCTS,
-				   unsigned int	cbFrameSize,
-				   bool bNeedACK,
-				   unsigned int	uDMAIdx,
-				   void *psEthHeader,
-				   unsigned short wCurrentRate);
-
-static unsigned int
-s_cbFillTxBufHead(struct vnt_private *p_device, unsigned char by_pkt_type,
-		  unsigned char *pbyTxBufferAddr,
-		  unsigned int uDMAIdx, struct vnt_tx_desc *pHeadTD,
-		  unsigned int uNodeIndex);
+static void s_vgenerate_tx_parameter(struct vnt_private *p_device,
+				     unsigned char by_pkt_type,
+				     struct vnt_tx_fifo_head *,
+				     void *pvRrvTime,
+				     void *pv_rts,
+				     void *pvCTS,
+				     unsigned int	cbFrameSize,
+				     bool bNeedACK,
+				     unsigned int	uDMAIdx,
+				     void *psEthHeader,
+				     unsigned short wCurrentRate);
+
+static unsigned int s_cbFillTxBufHead(struct vnt_private *p_device,
+				      unsigned char by_pkt_type,
+				      unsigned char *pbyTxBufferAddr,
+				      unsigned int uDMAIdx,
+				      struct vnt_tx_desc *pHeadTD,
+				      unsigned int uNodeIndex);
 
 static __le16 s_uFillDataHead(struct vnt_private *p_device,
 			      unsigned char by_pkt_type,
@@ -936,17 +937,17 @@ static void s_vFillCTSHead(struct vnt_private *p_device,
  -
  * unsigned int cbFrameSize, Hdr+Payload+FCS
  */
-static void s_vGenerateTxParameter(struct vnt_private *p_device,
-				   unsigned char by_pkt_type,
-				   struct vnt_tx_fifo_head *tx_buffer_head,
-				   void *pvRrvTime,
-				   void *pv_rts,
-				   void *pvCTS,
-				   unsigned int cbFrameSize,
-				   bool bNeedACK,
-				   unsigned int uDMAIdx,
-				   void *psEthHeader,
-				   unsigned short wCurrentRate)
+static void s_vgenerate_tx_parameter(struct vnt_private *p_device,
+				     unsigned char by_pkt_type,
+				     struct vnt_tx_fifo_head *tx_buffer_head,
+				     void *pvRrvTime,
+				     void *pv_rts,
+				     void *pvCTS,
+				     unsigned int cbFrameSize,
+				     bool bNeedACK,
+				     unsigned int uDMAIdx,
+				     void *psEthHeader,
+				     unsigned short wCurrentRate)
 {
 	u16 fifo_ctl = le16_to_cpu(tx_buffer_head->fifo_ctl);
 	bool b_dis_crc = false;
@@ -1223,8 +1224,8 @@ static unsigned int s_cbFillTxBufHead(struct vnt_private *p_device,
 	memset((void *)(pbyTxBufferAddr + wTxBufSize), 0, (cbHeaderLength - wTxBufSize));
 
 	/* Fill FIFO,RrvTime,RTS,and CTS */
-	s_vGenerateTxParameter(p_device, by_pkt_type, tx_buffer_head, pvRrvTime, pv_rts, pvCTS,
-			       cbFrameSize, bNeedACK, uDMAIdx, hdr, p_device->wCurrentRate);
+	s_vgenerate_tx_parameter(p_device, by_pkt_type, tx_buffer_head, pvRrvTime, pv_rts, pvCTS,
+				 cbFrameSize, bNeedACK, uDMAIdx, hdr, p_device->wCurrentRate);
 	/* Fill DataHead */
 	uDuration = s_uFillDataHead(p_device, by_pkt_type, pvTxDataHd, cbFrameSize, uDMAIdx,
 				    bNeedACK, 0, 0, uMACfragNum, by_fb_option,
@@ -10,7 +10,7 @@
  *
  * Functions:
- *      s_vGenerateTxParameter - Generate tx dma required parameter.
+ *      s_vgenerate_tx_parameter - Generate tx dma required parameter.
  *      vGenerateMACHeader - Translate 802.3 to 802.11 header
  *      cbGetFragCount - Calculate fragment number count
-- 
2.34.1

Powered by blists - more mailing lists